@@ -10,19 +10,32 @@
 #'    parameter can be set to \code{linelist_tags} if you wish to look for
 #'    duplicates on tagged columns only. Default is \code{NULL}.
 #'
+#' @details
+#' **Caveat:** In many epidemiological datasets, multiple rows may share the
+#' same value in one or more columns without being true duplicates.
+#' For example, several individuals might have the same  symptom onset date
+#' and admission date. Be cautious when using this function—especially when
+#' applying it to a single target column—to avoid incorrect identification
+#' or removal of valid entries.
+#'
 #' @returns The input data \code{<data.frame>} or \code{<linelist>} without the
 #'    duplicated rows identified from all or the specified columns.
 #' @export
 #'
 #' @examples
+#' data <- readRDS(
+#'   system.file("extdata", "test_linelist.RDS", package = "cleanepi")
+#' )
 #' no_dups <- remove_duplicates(
-#'   data = readRDS(
-#'     system.file("extdata", "test_linelist.RDS", package = "cleanepi")
-#'   ),
+#'   data = data,
 #'   target_columns = "linelist_tags"
 #' )
 #'
+#' # print the removed duplicates
+#' print_report(no_dups, "removed_duplicates")
 #'
+#' # print the detected duplicates
+#' print_report(no_dups, "found_duplicates")
 remove_duplicates <- function(data, target_columns = NULL) {
 
   # setting up the variables below to NULL to avoid linters
@@ -37,9 +50,9 @@ remove_duplicates <- function(data, target_columns = NULL) {
   # find duplicates
   dups <- find_duplicates(dat, target_columns)
   tmp_report <- attr(dups, "report")
-  if ("duplicated_rows" %in% names(tmp_report) &&
-      nrow(tmp_report[["duplicated_rows"]]) > 0L) {
-    dups <- tmp_report[["duplicated_rows"]]
+  if ("found_duplicates" %in% names(tmp_report) &&
+      nrow(tmp_report[["found_duplicates"]][["duplicated_rows"]]) > 0L) {
+    dups <- tmp_report[["found_duplicates"]][["duplicated_rows"]]
     report <- c(report, tmp_report)
     dat <- dat %>%
       dplyr::mutate(row_id = seq_len(nrow(dat)))
@@ -50,12 +63,15 @@ remove_duplicates <- function(data, target_columns = NULL) {
   dat <- dat %>%
     dplyr::distinct_at({{ target_columns }}, .keep_all = TRUE)
 
-  if ("duplicated_rows" %in% names(tmp_report) &&
-      nrow(tmp_report[["duplicated_rows"]]) > 0L) {
+  if ("found_duplicates" %in% names(tmp_report) &&
+      nrow(tmp_report[["found_duplicates"]][["duplicated_rows"]]) > 0L) {
     tmp_target_columns <- c("row_id", target_columns)
-    to_be_removed <- suppressMessages(dplyr::anti_join(dups, dat) %>%
-        dplyr::select({{ tmp_target_columns }}))
+    to_be_removed <- suppressMessages(dplyr::anti_join(dups, dat)) %>%
+      dplyr::select({{ tmp_target_columns }})
     report[["removed_duplicates"]] <- to_be_removed
+    # remove row_id column added for the anti join operation above between
+    # dups and dat
+    dat[["row_id"]] <- NULL
   }
 
   attr(dat, which = "report") <- report
@@ -86,13 +102,20 @@ remove_duplicates <- function(data, target_columns = NULL) {
 #' @export
 #'
 #' @examples
+#' data <- readRDS(
+#'   system.file("extdata", "test_linelist.RDS", package = "cleanepi")
+#' )
+#'
+#' # find duplicates across the following columns: "dt_onset", "dt_report",
+#' # "sex", and "outcome"
 #' dups <- find_duplicates(
-#'   data = readRDS(
-#'     system.file("extdata", "test_linelist.RDS", package = "cleanepi")
-#'   ),
+#'   data = data,
 #'   target_columns = c("dt_onset", "dt_report", "sex", "outcome")
 #' )
 #'
+#' # print the detected duplicates
+#' print_report(dups, "found_duplicates")
+#'
 find_duplicates <- function(data, target_columns = NULL) {
   # get the target column names
   target_columns <- retrieve_column_names(data, target_columns)
@@ -113,19 +136,18 @@ find_duplicates <- function(data, target_columns = NULL) {
   if (nrow(dups) > 0L) {
     cli::cli_inform(c(
       "!" = tr_("Found {.val {nrow(dups)}} duplicated row{?s} in the dataset."),
-      i = tr_("Use {.code attr(dat, \"report\")[[\"duplicated_rows\"]]} to access them, where {.val dat} is the object used to store the output from this operation.") # nolint: line_length_linter
+      i = tr_("Use {.code print_report(dat, \"found_duplicates\")} to access them, where {.val dat} is the object used to store the output from this operation.") # nolint: line_length_linter
     ))
     to_be_shown <- dups %>%
       dplyr::select(c("row_id", "group_id", {{ target_columns }}))
-    data <- add_to_report(
-      x = data,
-      key = "duplicated_rows",
-      value = to_be_shown
+    duplicates_report <- list(
+      duplicated_rows = to_be_shown,
+      duplicates_checked_from = target_columns
     )
     data <- add_to_report(
       x = data,
-      key = "duplicates_checked_from",
-      value = toString(target_columns)
+      key = "found_duplicates",
+      value = duplicates_report
     )
   } else {
     cli::cli_alert_info(
