@@ -16,14 +16,20 @@
 #' @export
 #'
 #' @examples
+#' data <- readRDS(
+#'   system.file("extdata", "test_df.RDS", package = "cleanepi")
+#' )
+#'
+#' # replace all occurrences of '-99' with NA
 #' cleaned_data <- replace_missing_values(
-#'   data = readRDS(
-#'     system.file("extdata", "test_df.RDS", package = "cleanepi")
-#'   ),
-#'   target_columns = "sex",
+#'   data = data,
+#'   target_columns = NULL,
 #'   na_strings = "-99"
 #' )
 #'
+#' # print the names of the columns where the replacement occurred
+#' print_report(cleaned_data, "missing_values_replaced_at")
+#'
 replace_missing_values <- function(data,
                                    target_columns = NULL,
                                    na_strings = cleanepi::common_na_strings) {
@@ -48,7 +54,7 @@ replace_missing_values <- function(data,
     data <- add_to_report(
       x = data,
       key = "missing_values_replaced_at",
-      value = toString(cols)
+      value = cols
     )
   } else {
     cli::cli_inform(c(
